==> haskell-warp-3.2.15-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.15
id: warp-3.2.15-BfNfITjtnouGil3XMpXCZm
key: warp-3.2.15-BfNfITjtnouGil3XMpXCZm
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 794b2c017d7606aedc6ba48dcffa9768
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/warp-3.2.15
library-dirs: /usr/lib/ghc-8.2.2/site-local/warp-3.2.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/warp-3.2.15
hs-libraries: HSwarp-3.2.15-BfNfITjtnouGil3XMpXCZm
depends:
    base-4.10.1.0 array-0.5.2.0 async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
    auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    containers-0.5.10.2 ghc-prim-0.5.1.1
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    iproute-1.7.1-EF6LnBWlkQ8AGHFTHCZDj4
    http2-1.6.3-B9YAvMuAikfGDf9rnduZbB
    simple-sendfile-0.2.26-HrDbFT9INP8Aar3UGVHacy
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    streaming-commons-0.1.18-8WddRtRT2Hn7uHOaceD3hl
    vault-0.3.0.7-GW96P6ByFi7BiPuu1OTaJk
    stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
    word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    http-date-0.0.6.1-6AP1uiEHt5BEEtML5u3TN2
    network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=7d406f0044aa7af43d5b6fcf63e521db
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             iproute-1.7.1-EF6LnBWlkQ8AGHFTHCZDj4=e5e4e95cc5005042b60bb61d1d965152
             http2-1.6.3-B9YAvMuAikfGDf9rnduZbB=9bf0a90cbe14af4792ff08e4b330e6c8
             simple-sendfile-0.2.26-HrDbFT9INP8Aar3UGVHacy=60fa9313a326e0f8b46fcf3c3d71ab25
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             streaming-commons-0.1.18-8WddRtRT2Hn7uHOaceD3hl=2bd1c2fc9719a500866ad19806be9f71
             vault-0.3.0.7-GW96P6ByFi7BiPuu1OTaJk=11401b0bc9beb731892d405fa705e459
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
             word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM=7fb6f62563c8e31582794e276e997542
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             http-date-0.0.6.1-6AP1uiEHt5BEEtML5u3TN2=49fe12cd6163ee8612531bf5788e51c2
             network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor=f013b5448241bfbc78fb9f4b90b2582b
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.16-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.16
id: warp-3.2.16-Ir5jXaCK05i6sqgp9xNysm
key: warp-3.2.16-Ir5jXaCK05i6sqgp9xNysm
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 9b33cb25f911a90ca45fb55ee7df8107
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/warp-3.2.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/warp-3.2.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/warp-3.2.16
hs-libraries: HSwarp-3.2.16-Ir5jXaCK05i6sqgp9xNysm
depends:
    base-4.10.1.0 array-0.5.2.0 async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    containers-0.5.10.2 ghc-prim-0.5.1.1
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    iproute-1.7.1-FOMJZeVPuEXEhUtov6bEOC
    http2-1.6.3-AswWrtI7C8u3BgFRSJEwTL
    simple-sendfile-0.2.27-6RG3rIR0l0cFUS4G6rjkHY
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    streaming-commons-0.1.19-Fc294krIqeVISM10DBfzmr
    vault-0.3.0.7-42kzp1yldz83jLl0I1vRZX
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    http-date-0.0.6.1-JKZ4mlYyGWjLWqEgYR1X2r
    network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             iproute-1.7.1-FOMJZeVPuEXEhUtov6bEOC=3c57dfb6881ff4481dc47334d39cc8e1
             http2-1.6.3-AswWrtI7C8u3BgFRSJEwTL=5e6fd11623141131ef8259fca5864997
             simple-sendfile-0.2.27-6RG3rIR0l0cFUS4G6rjkHY=a7778be7a8a37d569f0bd7c4623be075
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo=f23fc7107acf0017818154e8027ca65c
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             streaming-commons-0.1.19-Fc294krIqeVISM10DBfzmr=0d603588f914abd330f9780502df20d0
             vault-0.3.0.7-42kzp1yldz83jLl0I1vRZX=7ececdfffdd84dcce6af66eaff4068e0
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM=7fb6f62563c8e31582794e276e997542
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             http-date-0.0.6.1-JKZ4mlYyGWjLWqEgYR1X2r=bd11234bc9163fdfe4b1c3062b62311b
             network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM=58be2fae16c0eb05685e5ecea6703cff
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
